@@ -34,14 +34,13 @@ data-type, dimensions, byte order and offset
 This simple library has been made for manipulating exotic/unknown files format.
 """
 
-from __future__ import with_statement, print_function
-
 __authors__ = ["Gaël Goret", "Jérôme Kieffer", "Brian Pauw"]
 __contact__ = "gael.goret@esrf.fr"
-__license__ = "GPLv3+"
+__license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
 __version__ = "17/10/2012"
 
+import io
 from .fabioimage import FabioImage
 import numpy
 import logging
@@ -125,8 +124,11 @@ class BinaryImage(FabioImage):
         logger.info('estimation of the offset value (bytes): %s', totsize - size)
 
     def write(self, fname):
-        with open(fname, mode="wb") as outfile:
-            outfile.write(self.data.tobytes())
+        with self._open(fname, mode="wb") as outfile:
+            if isinstance(outfile, io.BufferedWriter):
+                self.data.tofile(outfile)
+            else:
+                outfile.write(self.data.tobytes())
 
 
 binaryimage = BinaryImage
