@@ -37,14 +37,12 @@ Authors: Henning O. Sorensen & Erik Knudsen
          and Jon Wright, Jerome Kieffer: ESRF
 
 """
-# get ready for python3
-from __future__ import with_statement, print_function, absolute_import, division
 
 __authors__ = ["Henning O. Sorensen", "Erik Knudsen", "Jon Wright", "Jérôme Kieffer"]
 __contact__ = "jerome.kieffer@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "ESRF"
-__date__ = "07/03/2019"
+__date__ = "11/12/2020"
 
 import os
 import logging
@@ -209,23 +207,23 @@ class _FabioArray(object):
         if sli == self.slice and self.area_sum is not None:
             pass
         elif sli == self.slice and self.roi is not None:
-            self.area_sum = self.roi.sum(dtype=numpy.float)
+            self.area_sum = self.roi.sum(dtype=numpy.float64)
         else:
             self.slice = sli
             self.roi = self.data[self.slice]
-            self.area_sum = self.roi.sum(dtype=numpy.float)
+            self.area_sum = self.roi.sum(dtype=numpy.float64)
         return self.area_sum
 
     def getmean(self):
         """ return the mean """
         if self.mean is None:
-            self.mean = self.data.mean(dtype=numpy.double)
+            self.mean = self.data.mean(dtype=numpy.float64)
         return self.mean
 
     def getstddev(self):
         """ return the standard deviation """
         if self.stddev is None:
-            self.stddev = self.data.std(dtype=numpy.double)
+            self.stddev = self.data.std(dtype=numpy.float64)
         return self.stddev
 
     @property
@@ -382,6 +380,14 @@ class FabioFrame(_FabioArray):
             return self._dtype
         return self.data.dtype
 
+    def next(self):
+        """Returns the next frame from it's file container.
+
+        :rtype: FabioFrame
+        """
+        container = self.file_container
+        return container.get_frame(self.file_index + 1)
+
 
 class FabioImage(_FabioArray):
     """A common object for images in fable
@@ -574,6 +580,7 @@ class FabioImage(_FabioArray):
         if self._classname is None:
             self._classname = str(self.__class__).replace("<class '", "").replace("'>", "").split(".")[-1]
         return self._classname
+
     classname = property(getclassname)
 
     def getframe(self, num):
@@ -858,8 +865,6 @@ class FabioImage(_FabioArray):
                 current_image = current_image.next()
             except IOError:
                 break
-        if sys.version_info[0:2] < (3, 5):
-            raise StopIteration()
 
 
 fabioimage = FabioImage
