@@ -28,25 +28,22 @@
 Stand-alone module which tries to offer interface to HDF5 via H5Py
 
 """
-from __future__ import absolute_import, print_function, division
 
 __author__ = "Jerome Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "23/10/2019"
+__date__ = "06/04/2020"
 __status__ = "beta"
 __docformat__ = 'restructuredtext'
 
 import logging
 import numpy
 import os
-import sys
 import time
 
 from .fabioutils import exists
 from ._version import version
-from .third_party import six
 
 logger = logging.getLogger(__name__)
 try:
@@ -84,7 +81,7 @@ def from_isotime(text, use_tz=False):
     """
     if isinstance(text, numpy.ndarray):
         text = text[0]
-    if six.PY3 and isinstance(text, six.binary_type):
+    if isinstance(text, bytes):
         text = text.decode("utf-8")
     else:
         text = str(text)
@@ -122,6 +119,7 @@ class Nexus(object):
 
     #TODO: make it thread-safe !!!
     """
+
     def __init__(self, filename, mode="r"):
         """
         Constructor
