@@ -8,12 +8,27 @@
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.#
 
 """Test Eiger images
 """
 
-from __future__ import print_function, with_statement, division, absolute_import
-
 import unittest
 import os
 import logging
@@ -84,6 +99,22 @@ class TestHdf5(unittest.TestCase):
         self.assertEqual(e.nframes, 50, "nframes OK")
         self.assertEqual(e.bpp, 4, "nframes OK")
 
+    def test_next_frames(self):
+        """ check the legacy next API"""
+        h5 = openimage(self.fn3)
+        frame_nb = 1
+        frame_id = 0
+        frame = h5
+        while True:
+            try:
+                frame = frame.next()
+                frame_id = frame.file_index
+                frame_nb += 1
+            except IndexError:
+                break
+        self.assertEqual(frame_nb, 50)
+        self.assertEqual(frame_id, 49)
+
 
 def suite():
     loadTests = unittest.defaultTestLoader.loadTestsFromTestCase
