@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding: utf-8
 #
 #    Project: X-ray image reader
 #             https://github.com/silx-kit/fabio
 #
-#    Copyright (C) 2015 European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2015-2020 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
@@ -26,7 +26,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""
+"""Unique place where the version number is defined.
 
 Module for version handling:
 
@@ -36,6 +36,7 @@ provides:
 * hexversion: 0x010203B4
 * strictversion = "1.2.3b4
 * debianversion = "1.2.3~beta4"
+* calc_hexversion: the function to transform a version_tuple into an integer
 
 This is called hexversion since it only really looks meaningful when viewed as the
 result of passing it to the built-in hex() function.
@@ -53,28 +54,33 @@ Thus 2.1.0a3 is hexversion 0x020100a3.
 
 """
 
-from __future__ import absolute_import, print_function, division
-
-__author__ = "Jerome Kieffer"
+__author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "03/04/2020"
+__date__ = "18/12/2020"
 __status__ = "production"
 __docformat__ = 'restructuredtext'
+__all__ = ["date", "version_info", "strictversion", "hexversion", "debianversion",
+           "calc_hexversion"]
 
 RELEASE_LEVEL_VALUE = {"dev": 0,
                        "alpha": 10,
                        "beta": 11,
-                       "gamma": 12,
-                       "rc": 13,
+                       "candidate": 12,
                        "final": 15}
 
+PRERELEASE_NORMALIZED_NAME = {"dev": "a",
+                              "alpha": "a",
+                              "beta": "b",
+                              "candidate": "rc"}
+
 MAJOR = 0
-MINOR = 10
-MICRO = 2
-RELEV = "final" # <16
+MINOR = 11
+MICRO = 0
+RELEV = "final"  # <16
 SERIAL = 0  # <16
+date = __date__
 
 from collections import namedtuple
 _version_info = namedtuple("version_info", ["major", "minor", "micro", "releaselevel", "serial"])
@@ -83,17 +89,13 @@ version_info = _version_info(MAJOR, MINOR, MICRO, RELEV, SERIAL)
 
 strictversion = version = debianversion = "%d.%d.%d" % version_info[:3]
 if version_info.releaselevel != "final":
-    version += "-%s%s" % version_info[-2:]
-    debianversion += "~adev%i" % version_info[-1] if RELEV == "dev" else "~%s%i" % version_info[-2:]
-    prerel = "a" if RELEASE_LEVEL_VALUE.get(version_info[3], 0) < 10 else "b"
-    if prerel not in "ab":
-        prerel = "a"
-    strictversion += prerel + str(version_info[-1])
-
-_PATTERN = None
+    _prerelease = PRERELEASE_NORMALIZED_NAME[version_info[3]]
+    version += "-%s%s" % (_prerelease, version_info[-1])
+    debianversion += "~adev%i" % version_info[-1] if RELEV == "dev" else "~%s%i" % (_prerelease, version_info[-1])
+    strictversion += _prerelease + str(version_info[-1])
 
 
-def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0, string=None):
+def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0):
     """Calculate the hexadecimal version number from the tuple version_info:
 
     :param major: integer
@@ -103,20 +105,6 @@ def calc_hexversion(major=0, minor=0, micro=0, releaselevel="dev", serial=0, str
     :param serial: integer
     :return: integer always increasing with revision numbers
     """
-    if string is not None:
-        global _PATTERN
-        if _PATTERN is None:
-            import re
-            _PATTERN = re.compile(r"(\d+)\.(\d+)\.(\d+)(\w+)?$")
-        result = _PATTERN.match(string)
-        if result is None:
-            raise ValueError("'%s' is not a valid version" % string)
-        result = result.groups()
-        major, minor, micro = int(result[0]), int(result[1]), int(result[2])
-        releaselevel = result[3]
-        if releaselevel is None:
-            releaselevel = 0
-
     try:
         releaselevel = int(releaselevel)
     except ValueError:
